/// <reference types="react" />
import { FieldConfig } from 'formik';
import { FieldProps } from 'practical-react-components-core';
export interface CheckboxGroupOption<V extends string | number> {
    readonly value: V;
    readonly label: string;
    readonly disabled?: boolean;
}
interface FormikCheckboxGroupProps<V extends string | number> extends Pick<FieldConfig, 'name' | 'validate'> {
    readonly options: ReadonlyArray<CheckboxGroupOption<V>>;
}
/**
 * Component that creates a group of checkboxes from the options prop.
 * The checkboxes is ordered in two columns, the first half of options in the first checkbox column,
 * last half of options in the right column.
 *
 * Eg:
 *
 * Options: [option1, option2, option3, option4]
 *
 * `[X] option1 [ ] option3`
 *
 * `[ ] option2 [X] option4`
 */
export declare function FormikCheckboxGroup<V extends string | number>({ name, validate, options, }: FormikCheckboxGroupProps<V>): JSX.Element;
export declare const FormikCheckboxGroupField: <V extends string | number>(props: FieldProps & FormikCheckboxGroupProps<V>) => import("react").ReactElement<any, any> | null;
export {};
